@@ -19,7 +19,7 @@ public:
     void setFilterText(const QString &newFilterText);
 
 protected:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 Q_SIGNALS:
     void filterTextChanged();
