@@ -38,7 +38,7 @@ int main(int argc, char **argv)
                          i18n("Configure debug settings"),
                          KAboutLicense::GPL_V2,
                          i18n("(c) %1 kdebugsettings authors", QStringLiteral("2023")));
-    aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
